@@ -149,8 +149,9 @@ class MRequest(object):
 
 
 class MCastRequest(object):
-    def __init__(self, sender_id, zid, message):
+    def __init__(self, seq_id, sender_id, zid, message):
         self.sender_id = sender_id
+        self.seq_id = seq_id
         self.zid = zid
         self.data = message
         self.command = None
@@ -165,7 +166,6 @@ class MCastRequest(object):
 def send_command_to(config, aws, endpoint, response):
     resp = response.make_response(config, aws)
     logging.info(aws.send_msg(endpoint, resp))
-    logging.info('command %s sended', response.message)
     if isinstance(response, MessageResponse) or isinstance(response, CastResponse) or isinstance(response, RawResponse):
         # 如果是Message消息就发APNS推送
         # msg = response.data.get('content').get('body').get('content')[:72]
@@ -182,8 +182,7 @@ class RawResponse(object):
         self.arn = target['arn']
 
     def make_response(self, config, aws):
-        message = base64.urlsafe_b64encode(self.message.encode())
-        return f"cast:{self.request.zid}:{message}"
+        return f"cast:{self.request.zid}:{self.message}"
 
 
 class Response(object):
@@ -352,9 +351,13 @@ def process_message(config, message):
             logging.error(formatError(e))
     else:
         #logging.info(f"get b64:{message.encode()}")
-        if message.startswith("cast:"):
-            _, zid, sender_id, _message = message.split(':')
-            return MCastRequest(zid, sender_id, _message)
+        if message.startswith("cast:") or message.startswith("cast_"):
+            cast, sender_id, zid, _message = message.split(':')
+            seqs = cast.split('_')
+            if len(seqs) > 1:
+                return MCastRequest(seqs[1], sender_id, zid, _message)
+            else:
+                return MCastRequest(None, sender_id, zid, _message)
         else:
             raw_message = base64.decodebytes(message.encode())
             pk = raw_message[:66]
@@ -394,10 +397,14 @@ def worker(pid, message):
         except Exception as e:
             logging.error(e)
         if resp:
-            response_text = resp.make_response(config, aws)
-            aws.send_msg(resp.endpoint, response_text)
-            logging.info(f'response:{resp.data}')
-            logging.info('message: sended!')
+            if hash('make_response'):
+                response_text = resp.make_response(config, aws)
+                aws.send_msg(resp.endpoint, response_text)
+                logging.info(f'response:{resp.data}')
+                logging.info('message: sended!')
+            else:
+                logging.info('Blank Response！')
+
 
 
 def start(workers=0):
